# PyMoX-Kit

Trousse à outils utiles pour devs en PyMoX# Test_Kit

GH : [https://github.com/PyMoX-fr/Kit](https://github.com/PyMoX-fr/Kit)

![WinSxS Ready](https://img.shields.io/badge/Windows-Ready-0078D6?logo=windows&logoColor=white)
![Linux Compatible](https://img.shields.io/badge/Linux-Compatible-FCC624?logo=linux&logoColor=#FCC624)
[![Python](https://img.shields.io/badge/Python-3.11→3.14-3776AB?logo=python)](https://www.python.org)
[![PyMoX-Kit Version](https://img.shields.io/pypi/v/pymox-kit?logo=python&logoColor=white&label=PyMoX-Kit)](https://pypi.org/project/pymox-kit)
[![GitHub Passing](https://img.shields.io/badge/GitHub-Passing-2ea44f?logo=github&logoColor=white)](https://github.com/PyMoX-fr/Kit)

---

## Installation

```bash
py -m venv .venv
.\.venv\Scripts\activate
py -m pip install --upgrade pip
pip install pymox_kit
```

## Utilisation

```python
from pytmox_kit import *

print(Hello())
```

## Contribution

Pour tester la lib **PyMox_Kit** : [![GitHub](https://img.shields.io/badge/GitHub-Dépôt_Test_Kit-2ea44f?logo=github&logoColor=white)](https://github.com/PyMoX-fr/Kit)

Si volonté d' ↑ la lib : → Merge Request [![GitHub Passing](https://img.shields.io/badge/GitHub-PyMox_Kit-2ea44f?logo=github&logoColor=white)](https://github.com/PyMoX-fr/Kit)


## Help

[![GitHub Issue](https://img.shields.io/badge/GitHub-PyMox_Kit_Issues-2ea44f?logo=github&logoColor=white)](https://github.com/PyMoX-fr/Kit/issues)
